@@ -37,7 +37,7 @@
 
 __author__ = "Michael Imelfort"
 __copyright__ = "Copyright 2012"
-__credits__ = ["Michael Imelfort"]
+__credits__ = ["Michael Imelfort", "Connor Skennerton"]
 __license__ = "GPL3"
 __version__ = "0.1.1"
 __maintainer__ = "Michael Imelfort"
